#!/bin/sh

# This script is intended to be used on SX1302 CoreCell platform, it performs
# the following actions:
#       - export/unpexort GPIO18 used to reset the SX1302 chip
#
# Usage examples:
#       ./reset_lgw.sh stop
#       ./reset_lgw.sh start

# GPIO mapping has to be adapted with HW
#

SX1302_RESET_PIN=18

GPIO_EXE=raspi-gpio
pinctrl help > /dev/null
if [ $? -eq 0 ];then
    GPIO_EXE=pinctrl
fi

WAIT_GPIO() {
    sleep 0.1
}

init() {
    # setup GPIOs
    ${GPIO_EXE} set $SX1302_RESET_PIN op
    WAIT_GPIO
}

reset() {
    echo "CoreCell reset through GPIO$SX1302_RESET_PIN..."

    ${GPIO_EXE} set $SX1302_RESET_PIN dh
    WAIT_GPIO
    ${GPIO_EXE} set $SX1302_RESET_PIN dl
    WAIT_GPIO
}

case "$1" in
    start)
    # term # just in case
    init
    reset
    ;;
    stop)
    reset
    # term
    ;;
    *)
    echo "Usage: $0 {start|stop}"
    exit 1
    ;;
esac

exit 0
